==> nats.c_3.2.0.orig.tar.gz: nats.c-3.2.0/doc/html/search/all_12.js <==
var searchData=
[
  ['samplefrequency_0',['SampleFrequency',['../structjs_consumer_config.html#a43f40b8eef0074b4146fb945b4645584',1,'jsConsumerConfig']]],
  ['sealed_1',['Sealed',['../structjs_stream_config.html#aede3fd2ab13d230eda14c96f9997e1b7',1,'jsStreamConfig']]],
  ['sequence_2',['Sequence',['../structjs_msg_meta_data.html#a23d5fd1992033164c73d5c2a16a4e321',1,'jsMsgMetaData::Sequence()'],['../structjs_pub_ack.html#a01d302d5e1a2e71487a8c74c3fed1691',1,'jsPubAck::Sequence()'],['../structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html#a0d61e5d3c9c518f455549086ababe7f6',1,'jsOptions::jsOptionsStream::jsOptionsStreamPurge::Sequence()']]],
  ['sources_3',['Sources',['../structjs_stream_config.html#a8f0ee08922e5b2108082b5b9e4a6284b',1,'jsStreamConfig::Sources()'],['../structjs_stream_info.html#a2e7ca48a93fe57265609e7e0cd3fa386',1,'jsStreamInfo::Sources()']]],
  ['sourceslen_4',['SourcesLen',['../structjs_stream_config.html#a34960d6acc710c2f32b563f4bb7c9c0a',1,'jsStreamConfig::SourcesLen()'],['../structjs_stream_info.html#af14110cb1f8e16e3dade8d9f7c2fd672',1,'jsStreamInfo::SourcesLen()']]],
  ['stallwait_5',['StallWait',['../structjs_options_1_1js_options_publish_async.html#ada58fefe0ed40157b5f5d44b9dd175f9',1,'jsOptions::jsOptionsPublishAsync']]],
  ['stanconnection_6',['stanConnection',['../group__types_group.html#ga9e826493769d23086cfccefe95cdf64c',1,'nats.h']]],
  ['stanconnection_5fclose_7',['stanConnection_Close',['../group__stan_conn_mgt_group.html#ga4952a7f65a53fdb5ca1c26b1a1656f1d',1,'nats.h']]],
  ['stanconnection_5fconnect_8',['stanConnection_Connect',['../group__stan_conn_mgt_group.html#ga35e0e6e5e3b7f3818a3ac3600efb8f8f',1,'nats.h']]],
  ['stanconnection_5fdestroy_9',['stanConnection_Destroy',['../group__stan_conn_mgt_group.html#gaea095eec18fdf04e06de16711f8b1a04',1,'nats.h']]],
  ['stanconnection_5fgetnatsconnection_10',['stanConnection_GetNATSConnection',['../group__stan_conn_mgt_group.html#ga166ec494a55c9b1f9ebafd2294e05ff6',1,'nats.h']]],
  ['stanconnection_5fpublish_11',['stanConnection_Publish',['../group__stan_conn_pub_group.html#ga24f3f7f709b15fe53e1edaeead08fc7d',1,'nats.h']]],
  ['stanconnection_5fpublishasync_12',['stanConnection_PublishAsync',['../group__stan_conn_pub_group.html#ga0c4d1e4615f8ac834f0a4021f75d39f0',1,'nats.h']]],
  ['stanconnection_5fqueuesubscribe_13',['stanConnection_QueueSubscribe',['../group__stan_conn_sub_group.html#ga17d42bf9a4fa39470561a1a668e6b4a2',1,'nats.h']]],
  ['stanconnection_5freleasenatsconnection_14',['stanConnection_ReleaseNATSConnection',['../group__stan_conn_mgt_group.html#ga2e56a93825e1214a5ab688860e2a8ce6',1,'nats.h']]],
  ['stanconnection_5fsubscribe_15',['stanConnection_Subscribe',['../group__stan_conn_sub_group.html#gae545358fdc493baf6d29429a8156781f',1,'nats.h']]],
  ['stanconnectionlosthandler_16',['stanConnectionLostHandler',['../group__callbacks_group.html#gac34092f6c698374f86ad349302bdd55c',1,'nats.h']]],
  ['stanconnoptions_17',['stanConnOptions',['../group__types_group.html#ga13d64411878ba13a6ca39c915f2447c1',1,'nats.h']]],
  ['stanconnoptions_5fcreate_18',['stanConnOptions_Create',['../group__stan_conn_opts_group.html#gaff52a1ce90253b4bdbb0005fca4f71b6',1,'nats.h']]],
  ['stanconnoptions_5fdestroy_19',['stanConnOptions_Destroy',['../group__stan_conn_opts_group.html#ga83fd0a29b136cbfb643be642eb2fa726',1,'nats.h']]],
  ['stanconnoptions_5fsetconnectionlosthandler_20',['stanConnOptions_SetConnectionLostHandler',['../group__stan_conn_opts_group.html#ga19ba15c8001aa835b261eea3a309e6d3',1,'nats.h']]],
  ['stanconnoptions_5fsetconnectionwait_21',['stanConnOptions_SetConnectionWait',['../group__stan_conn_opts_group.html#ga66c72c482696d9ceca71fced7cbb1264',1,'nats.h']]],
  ['stanconnoptions_5fsetdiscoveryprefix_22',['stanConnOptions_SetDiscoveryPrefix',['../group__stan_conn_opts_group.html#ga07105d1d00878bba19f47243b2c88402',1,'nats.h']]],
  ['stanconnoptions_5fsetmaxpubacksinflight_23',['stanConnOptions_SetMaxPubAcksInflight',['../group__stan_conn_opts_group.html#ga29eee1be7eff749aeac3bab60d1b0405',1,'nats.h']]],
  ['stanconnoptions_5fsetnatsoptions_24',['stanConnOptions_SetNATSOptions',['../group__stan_conn_opts_group.html#gae3fc9a4daa7f85367811a313857337b4',1,'nats.h']]],
  ['stanconnoptions_5fsetpings_25',['stanConnOptions_SetPings',['../group__stan_conn_opts_group.html#gad835223f08fbeae2a3c7a34d3fa1550b',1,'nats.h']]],
  ['stanconnoptions_5fsetpubackwait_26',['stanConnOptions_SetPubAckWait',['../group__stan_conn_opts_group.html#ga36f2ee441562dcf619d6e020b823fc96',1,'nats.h']]],
  ['stanconnoptions_5fseturl_27',['stanConnOptions_SetURL',['../group__stan_conn_opts_group.html#ga3c6d511fc1e1febcdf5344960de5a0b3',1,'nats.h']]],
  ['stanmsg_28',['stanMsg',['../group__types_group.html#ga2cf5db7703b42d97abe56a3e83b2a87d',1,'nats.h']]],
  ['stanmsg_5fdestroy_29',['stanMsg_Destroy',['../group__stan_msg_group.html#gacd0059fb499963f5b2eae18053e5f74f',1,'nats.h']]],
  ['stanmsg_5fgetdata_30',['stanMsg_GetData',['../group__stan_msg_group.html#ga2f27fbfb79a46c52e079f670c59e1260',1,'nats.h']]],
  ['stanmsg_5fgetdatalength_31',['stanMsg_GetDataLength',['../group__stan_msg_group.html#ga7d1e394a686bc25ab7376b7f28b9e777',1,'nats.h']]],
  ['stanmsg_5fgetsequence_32',['stanMsg_GetSequence',['../group__stan_msg_group.html#ga98b66ff73447e1d7e329edbfcde782b5',1,'nats.h']]],
  ['stanmsg_5fgettimestamp_33',['stanMsg_GetTimestamp',['../group__stan_msg_group.html#ga2fa524b11e9621cf46ca9b1a3ca66452',1,'nats.h']]],
  ['stanmsg_5fisredelivered_34',['stanMsg_IsRedelivered',['../group__stan_msg_group.html#ga8e537d014b89d9d7da7906b2ee75d5c0',1,'nats.h']]],
  ['stanmsghandler_35',['stanMsgHandler',['../group__callbacks_group.html#gaf7456e37fa14f1834d9048d3789e9409',1,'nats.h']]],
  ['stanpubackhandler_36',['stanPubAckHandler',['../group__callbacks_group.html#gad5d6a685731b3bf635995b7375af4d18',1,'nats.h']]],
  ['stansuboptions_37',['stanSubOptions',['../group__types_group.html#ga023712711f5c289663fc2223e83686d3',1,'nats.h']]],
  ['stansuboptions_5fcreate_38',['stanSubOptions_Create',['../group__stan_sub_opts_group.html#gad87a2cef4f4ddf64696f9864773c37cf',1,'nats.h']]],
  ['stansuboptions_5fdeliverallavailable_39',['stanSubOptions_DeliverAllAvailable',['../group__stan_sub_opts_group.html#gab09b81358e93199a4631eb06f1ec179f',1,'nats.h']]],
  ['stansuboptions_5fdestroy_40',['stanSubOptions_Destroy',['../group__stan_sub_opts_group.html#ga1b56877d0a6729e148c9c288e2b88e3f',1,'nats.h']]],
  ['stansuboptions_5fsetackwait_41',['stanSubOptions_SetAckWait',['../group__stan_sub_opts_group.html#gafbb4e6c74978c4e8f30f016c20cc2bdf',1,'nats.h']]],
  ['stansuboptions_5fsetdurablename_42',['stanSubOptions_SetDurableName',['../group__stan_sub_opts_group.html#gaa018bceba99ef3726157e87c6918ab14',1,'nats.h']]],
  ['stansuboptions_5fsetmanualackmode_43',['stanSubOptions_SetManualAckMode',['../group__stan_sub_opts_group.html#ga6f49ae2629e49d2bfa35990cf030bf83',1,'nats.h']]],
  ['stansuboptions_5fsetmaxinflight_44',['stanSubOptions_SetMaxInflight',['../group__stan_sub_opts_group.html#ga35efbdea888e00440c500845064931c0',1,'nats.h']]],
  ['stansuboptions_5fstartatsequence_45',['stanSubOptions_StartAtSequence',['../group__stan_sub_opts_group.html#ga6cb7f6e1ac697d16959f9042eeb84dc1',1,'nats.h']]],
  ['stansuboptions_5fstartattime_46',['stanSubOptions_StartAtTime',['../group__stan_sub_opts_group.html#gaafd7a553486eea3c9d309da0744a3608',1,'nats.h']]],
  ['stansuboptions_5fstartattimedelta_47',['stanSubOptions_StartAtTimeDelta',['../group__stan_sub_opts_group.html#ga27d9175901997b8468997019746599b5',1,'nats.h']]],
  ['stansuboptions_5fstartwithlastreceived_48',['stanSubOptions_StartWithLastReceived',['../group__stan_sub_opts_group.html#ga856a74e31f3307faf988747c1f88717c',1,'nats.h']]],
  ['stansubscription_49',['stanSubscription',['../group__types_group.html#gae4dae869fb614536f0f027c2e2660cc5',1,'nats.h']]],
  ['stansubscription_5fackmsg_50',['stanSubscription_AckMsg',['../group__stan_sub_group.html#ga3a1cca9fa3ea54fcf7a43fd1335a26d3',1,'nats.h']]],
  ['stansubscription_5fclose_51',['stanSubscription_Close',['../group__stan_sub_group.html#gacfa3a7b4fa333c84acfa7521fbbb5bcc',1,'nats.h']]],
  ['stansubscription_5fdestroy_52',['stanSubscription_Destroy',['../group__stan_sub_group.html#ga3f6ce924f6a1830a55e30e9910aad4ba',1,'nats.h']]],
  ['stansubscription_5fsetoncompletecb_53',['stanSubscription_SetOnCompleteCB',['../group__stan_sub_group.html#ga7b039908ec45cfc2c16ec61ba8daca9d',1,'nats.h']]],
  ['stansubscription_5funsubscribe_54',['stanSubscription_Unsubscribe',['../group__stan_sub_group.html#gafa428a7e0f6800216cb06fd738bd235e',1,'nats.h']]],
  ['state_55',['State',['../structjs_stream_info.html#a766ac56dec3bd19fa5b9861fb5f64397',1,'jsStreamInfo']]],
  ['statistics_56',['Statistics',['../group__stats_group.html',1,'']]],
  ['status_57',['Status',['../group__status_group.html',1,'']]],
  ['status_2eh_58',['status.h',['../status_8h.html',1,'']]],
  ['storage_59',['Storage',['../structjs_stream_config.html#a59c34091f336eafa77da2991c852c0d8',1,'jsStreamConfig']]],
  ['storagetype_60',['StorageType',['../structkv_config.html#ad5db9a58224d93ab86b4cfc4c46f1897',1,'kvConfig']]],
  ['store_61',['Store',['../structjs_account_info.html#ad1c254c5b8f11f57062a4e2d5fb10ae3',1,'jsAccountInfo']]],
  ['stream_62',['Stream',['../structjs_options.html#ae50544ee0ef8dd7d02ef9802805807ae',1,'jsOptions::Stream()'],['../structjs_pub_ack.html#a4fd5e6cdb7217d72c553afcc75358893',1,'jsPubAck::Stream()'],['../structjs_msg_meta_data.html#a32e2a9438d2dc769f7f64d2f8897abc4',1,'jsMsgMetaData::Stream()'],['../structjs_consumer_info.html#a8f21939613163a7c0ebfb521aa471260',1,'jsConsumerInfo::Stream()'],['../structjs_sequence_info.html#ab52c55c1d0edd20e064870b490b4b990',1,'jsSequenceInfo::Stream()'],['../structjs_sequence_pair.html#ab051e0815302c48ba6122bd18d9d76f7',1,'jsSequencePair::Stream()'],['../structjs_sub_options.html#a856a6af4a7ff5aa2e736338091e69484',1,'jsSubOptions::Stream()'],['../structjs_consumer_sequence_mismatch.html#aad6a17af1719c023c38a6fd254b73f8e',1,'jsConsumerSequenceMismatch::Stream()']]],
  ['streaming_20connection_63',['Streaming Connection',['../group__stan_conn_group.html',1,'']]],
  ['streaming_20connection_20options_64',['Streaming Connection Options',['../group__stan_conn_opts_group.html',1,'']]],
  ['streaming_20message_65',['Streaming Message',['../group__stan_msg_group.html',1,'']]],
  ['streaming_20subscription_66',['Streaming Subscription',['../group__stan_sub_group.html',1,'']]],
  ['streaming_20subscription_20options_67',['Streaming Subscription Options',['../group__stan_sub_opts_group.html',1,'']]],
  ['streams_68',['Streams',['../structjs_account_info.html#a17317abf03effdcdedc2003fca8adc71',1,'jsAccountInfo']]],
  ['subject_69',['Subject',['../structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html#aa99e6ee3bef1c22243f01544181315fe',1,'jsOptions::jsOptionsStream::jsOptionsStreamPurge']]],
  ['subjects_70',['Subjects',['../structjs_stream_config.html#a0c5f3354073dbe72650e3db7f59a47af',1,'jsStreamConfig']]],
  ['subjectslen_71',['SubjectsLen',['../structjs_stream_config.html#ab2186aae798df6c222b3fa69e31597e1',1,'jsStreamConfig']]],
  ['subscribing_72',['Subscribing',['../group__conn_sub_group.html',1,'(Global Namespace)'],['../group__js_sub_group.html',1,'(Global Namespace)'],['../group__stan_conn_sub_group.html',1,'(Global Namespace)']]],
  ['subscription_73',['Subscription',['../group__sub_group.html',1,'']]]
];

==> nats.c_3.3.0.orig.tar.gz: nats.c-3.3.0/doc/html/search/all_12.js <==
var searchData=
[
  ['samplefrequency_0',['SampleFrequency',['../structjs_consumer_config.html#a43f40b8eef0074b4146fb945b4645584',1,'jsConsumerConfig']]],
  ['sealed_1',['Sealed',['../structjs_stream_config.html#aede3fd2ab13d230eda14c96f9997e1b7',1,'jsStreamConfig']]],
  ['sequence_2',['Sequence',['../structjs_msg_meta_data.html#a23d5fd1992033164c73d5c2a16a4e321',1,'jsMsgMetaData::Sequence()'],['../structjs_pub_ack.html#a01d302d5e1a2e71487a8c74c3fed1691',1,'jsPubAck::Sequence()'],['../structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html#a0d61e5d3c9c518f455549086ababe7f6',1,'jsOptions::jsOptionsStream::jsOptionsStreamPurge::Sequence()']]],
  ['sources_3',['Sources',['../structjs_stream_config.html#a8f0ee08922e5b2108082b5b9e4a6284b',1,'jsStreamConfig::Sources()'],['../structjs_stream_info.html#a2e7ca48a93fe57265609e7e0cd3fa386',1,'jsStreamInfo::Sources()']]],
  ['sourceslen_4',['SourcesLen',['../structjs_stream_config.html#a34960d6acc710c2f32b563f4bb7c9c0a',1,'jsStreamConfig::SourcesLen()'],['../structjs_stream_info.html#af14110cb1f8e16e3dade8d9f7c2fd672',1,'jsStreamInfo::SourcesLen()']]],
  ['stallwait_5',['StallWait',['../structjs_options_1_1js_options_publish_async.html#ada58fefe0ed40157b5f5d44b9dd175f9',1,'jsOptions::jsOptionsPublishAsync']]],
  ['stanconnection_6',['stanConnection',['../group__types_group.html#ga9e826493769d23086cfccefe95cdf64c',1,'nats.h']]],
  ['stanconnection_5fclose_7',['stanConnection_Close',['../group__stan_conn_mgt_group.html#ga4952a7f65a53fdb5ca1c26b1a1656f1d',1,'nats.h']]],
  ['stanconnection_5fconnect_8',['stanConnection_Connect',['../group__stan_conn_mgt_group.html#ga35e0e6e5e3b7f3818a3ac3600efb8f8f',1,'nats.h']]],
  ['stanconnection_5fdestroy_9',['stanConnection_Destroy',['../group__stan_conn_mgt_group.html#gaea095eec18fdf04e06de16711f8b1a04',1,'nats.h']]],
  ['stanconnection_5fgetnatsconnection_10',['stanConnection_GetNATSConnection',['../group__stan_conn_mgt_group.html#ga166ec494a55c9b1f9ebafd2294e05ff6',1,'nats.h']]],
  ['stanconnection_5fpublish_11',['stanConnection_Publish',['../group__stan_conn_pub_group.html#ga24f3f7f709b15fe53e1edaeead08fc7d',1,'nats.h']]],
  ['stanconnection_5fpublishasync_12',['stanConnection_PublishAsync',['../group__stan_conn_pub_group.html#ga0c4d1e4615f8ac834f0a4021f75d39f0',1,'nats.h']]],
  ['stanconnection_5fqueuesubscribe_13',['stanConnection_QueueSubscribe',['../group__stan_conn_sub_group.html#ga17d42bf9a4fa39470561a1a668e6b4a2',1,'nats.h']]],
  ['stanconnection_5freleasenatsconnection_14',['stanConnection_ReleaseNATSConnection',['../group__stan_conn_mgt_group.html#ga2e56a93825e1214a5ab688860e2a8ce6',1,'nats.h']]],
  ['stanconnection_5fsubscribe_15',['stanConnection_Subscribe',['../group__stan_conn_sub_group.html#gae545358fdc493baf6d29429a8156781f',1,'nats.h']]],
  ['stanconnectionlosthandler_16',['stanConnectionLostHandler',['../group__callbacks_group.html#gac34092f6c698374f86ad349302bdd55c',1,'nats.h']]],
  ['stanconnoptions_17',['stanConnOptions',['../group__types_group.html#ga13d64411878ba13a6ca39c915f2447c1',1,'nats.h']]],
  ['stanconnoptions_5fcreate_18',['stanConnOptions_Create',['../group__stan_conn_opts_group.html#gaff52a1ce90253b4bdbb0005fca4f71b6',1,'nats.h']]],
  ['stanconnoptions_5fdestroy_19',['stanConnOptions_Destroy',['../group__stan_conn_opts_group.html#ga83fd0a29b136cbfb643be642eb2fa726',1,'nats.h']]],
  ['stanconnoptions_5fsetconnectionlosthandler_20',['stanConnOptions_SetConnectionLostHandler',['../group__stan_conn_opts_group.html#ga19ba15c8001aa835b261eea3a309e6d3',1,'nats.h']]],
  ['stanconnoptions_5fsetconnectionwait_21',['stanConnOptions_SetConnectionWait',['../group__stan_conn_opts_group.html#ga66c72c482696d9ceca71fced7cbb1264',1,'nats.h']]],
  ['stanconnoptions_5fsetdiscoveryprefix_22',['stanConnOptions_SetDiscoveryPrefix',['../group__stan_conn_opts_group.html#ga07105d1d00878bba19f47243b2c88402',1,'nats.h']]],
  ['stanconnoptions_5fsetmaxpubacksinflight_23',['stanConnOptions_SetMaxPubAcksInflight',['../group__stan_conn_opts_group.html#ga29eee1be7eff749aeac3bab60d1b0405',1,'nats.h']]],
  ['stanconnoptions_5fsetnatsoptions_24',['stanConnOptions_SetNATSOptions',['../group__stan_conn_opts_group.html#gae3fc9a4daa7f85367811a313857337b4',1,'nats.h']]],
  ['stanconnoptions_5fsetpings_25',['stanConnOptions_SetPings',['../group__stan_conn_opts_group.html#gad835223f08fbeae2a3c7a34d3fa1550b',1,'nats.h']]],
  ['stanconnoptions_5fsetpubackwait_26',['stanConnOptions_SetPubAckWait',['../group__stan_conn_opts_group.html#ga36f2ee441562dcf619d6e020b823fc96',1,'nats.h']]],
  ['stanconnoptions_5fseturl_27',['stanConnOptions_SetURL',['../group__stan_conn_opts_group.html#ga3c6d511fc1e1febcdf5344960de5a0b3',1,'nats.h']]],
  ['stanmsg_28',['stanMsg',['../group__types_group.html#ga2cf5db7703b42d97abe56a3e83b2a87d',1,'nats.h']]],
  ['stanmsg_5fdestroy_29',['stanMsg_Destroy',['../group__stan_msg_group.html#gacd0059fb499963f5b2eae18053e5f74f',1,'nats.h']]],
  ['stanmsg_5fgetdata_30',['stanMsg_GetData',['../group__stan_msg_group.html#ga2f27fbfb79a46c52e079f670c59e1260',1,'nats.h']]],
  ['stanmsg_5fgetdatalength_31',['stanMsg_GetDataLength',['../group__stan_msg_group.html#ga7d1e394a686bc25ab7376b7f28b9e777',1,'nats.h']]],
  ['stanmsg_5fgetsequence_32',['stanMsg_GetSequence',['../group__stan_msg_group.html#ga98b66ff73447e1d7e329edbfcde782b5',1,'nats.h']]],
  ['stanmsg_5fgettimestamp_33',['stanMsg_GetTimestamp',['../group__stan_msg_group.html#ga2fa524b11e9621cf46ca9b1a3ca66452',1,'nats.h']]],
  ['stanmsg_5fisredelivered_34',['stanMsg_IsRedelivered',['../group__stan_msg_group.html#ga8e537d014b89d9d7da7906b2ee75d5c0',1,'nats.h']]],
  ['stanmsghandler_35',['stanMsgHandler',['../group__callbacks_group.html#gaf7456e37fa14f1834d9048d3789e9409',1,'nats.h']]],
  ['stanpubackhandler_36',['stanPubAckHandler',['../group__callbacks_group.html#gad5d6a685731b3bf635995b7375af4d18',1,'nats.h']]],
  ['stansuboptions_37',['stanSubOptions',['../group__types_group.html#ga023712711f5c289663fc2223e83686d3',1,'nats.h']]],
  ['stansuboptions_5fcreate_38',['stanSubOptions_Create',['../group__stan_sub_opts_group.html#gad87a2cef4f4ddf64696f9864773c37cf',1,'nats.h']]],
  ['stansuboptions_5fdeliverallavailable_39',['stanSubOptions_DeliverAllAvailable',['../group__stan_sub_opts_group.html#gab09b81358e93199a4631eb06f1ec179f',1,'nats.h']]],
  ['stansuboptions_5fdestroy_40',['stanSubOptions_Destroy',['../group__stan_sub_opts_group.html#ga1b56877d0a6729e148c9c288e2b88e3f',1,'nats.h']]],
  ['stansuboptions_5fsetackwait_41',['stanSubOptions_SetAckWait',['../group__stan_sub_opts_group.html#gafbb4e6c74978c4e8f30f016c20cc2bdf',1,'nats.h']]],
  ['stansuboptions_5fsetdurablename_42',['stanSubOptions_SetDurableName',['../group__stan_sub_opts_group.html#gaa018bceba99ef3726157e87c6918ab14',1,'nats.h']]],
  ['stansuboptions_5fsetmanualackmode_43',['stanSubOptions_SetManualAckMode',['../group__stan_sub_opts_group.html#ga6f49ae2629e49d2bfa35990cf030bf83',1,'nats.h']]],
  ['stansuboptions_5fsetmaxinflight_44',['stanSubOptions_SetMaxInflight',['../group__stan_sub_opts_group.html#ga35efbdea888e00440c500845064931c0',1,'nats.h']]],
  ['stansuboptions_5fstartatsequence_45',['stanSubOptions_StartAtSequence',['../group__stan_sub_opts_group.html#ga6cb7f6e1ac697d16959f9042eeb84dc1',1,'nats.h']]],
  ['stansuboptions_5fstartattime_46',['stanSubOptions_StartAtTime',['../group__stan_sub_opts_group.html#gaafd7a553486eea3c9d309da0744a3608',1,'nats.h']]],
  ['stansuboptions_5fstartattimedelta_47',['stanSubOptions_StartAtTimeDelta',['../group__stan_sub_opts_group.html#ga27d9175901997b8468997019746599b5',1,'nats.h']]],
  ['stansuboptions_5fstartwithlastreceived_48',['stanSubOptions_StartWithLastReceived',['../group__stan_sub_opts_group.html#ga856a74e31f3307faf988747c1f88717c',1,'nats.h']]],
  ['stansubscription_49',['stanSubscription',['../group__types_group.html#gae4dae869fb614536f0f027c2e2660cc5',1,'nats.h']]],
  ['stansubscription_5fackmsg_50',['stanSubscription_AckMsg',['../group__stan_sub_group.html#ga3a1cca9fa3ea54fcf7a43fd1335a26d3',1,'nats.h']]],
  ['stansubscription_5fclose_51',['stanSubscription_Close',['../group__stan_sub_group.html#gacfa3a7b4fa333c84acfa7521fbbb5bcc',1,'nats.h']]],
  ['stansubscription_5fdestroy_52',['stanSubscription_Destroy',['../group__stan_sub_group.html#ga3f6ce924f6a1830a55e30e9910aad4ba',1,'nats.h']]],
  ['stansubscription_5fsetoncompletecb_53',['stanSubscription_SetOnCompleteCB',['../group__stan_sub_group.html#ga7b039908ec45cfc2c16ec61ba8daca9d',1,'nats.h']]],
  ['stansubscription_5funsubscribe_54',['stanSubscription_Unsubscribe',['../group__stan_sub_group.html#gafa428a7e0f6800216cb06fd738bd235e',1,'nats.h']]],
  ['state_55',['State',['../structjs_stream_info.html#a766ac56dec3bd19fa5b9861fb5f64397',1,'jsStreamInfo']]],
  ['statistics_56',['Statistics',['../group__stats_group.html',1,'']]],
  ['status_57',['Status',['../group__status_group.html',1,'']]],
  ['status_2eh_58',['status.h',['../status_8h.html',1,'']]],
  ['storage_59',['Storage',['../structjs_stream_config.html#a59c34091f336eafa77da2991c852c0d8',1,'jsStreamConfig']]],
  ['storagetype_60',['StorageType',['../structkv_config.html#ad5db9a58224d93ab86b4cfc4c46f1897',1,'kvConfig']]],
  ['store_61',['Store',['../structjs_account_info.html#ad1c254c5b8f11f57062a4e2d5fb10ae3',1,'jsAccountInfo']]],
  ['stream_62',['Stream',['../structjs_options.html#ae50544ee0ef8dd7d02ef9802805807ae',1,'jsOptions::Stream()'],['../structjs_pub_ack.html#a4fd5e6cdb7217d72c553afcc75358893',1,'jsPubAck::Stream()'],['../structjs_msg_meta_data.html#a32e2a9438d2dc769f7f64d2f8897abc4',1,'jsMsgMetaData::Stream()'],['../structjs_consumer_info.html#a8f21939613163a7c0ebfb521aa471260',1,'jsConsumerInfo::Stream()'],['../structjs_sequence_info.html#ab52c55c1d0edd20e064870b490b4b990',1,'jsSequenceInfo::Stream()'],['../structjs_sequence_pair.html#ab051e0815302c48ba6122bd18d9d76f7',1,'jsSequencePair::Stream()'],['../structjs_sub_options.html#a856a6af4a7ff5aa2e736338091e69484',1,'jsSubOptions::Stream()'],['../structjs_consumer_sequence_mismatch.html#aad6a17af1719c023c38a6fd254b73f8e',1,'jsConsumerSequenceMismatch::Stream()']]],
  ['streaming_20connection_63',['Streaming Connection',['../group__stan_conn_group.html',1,'']]],
  ['streaming_20connection_20options_64',['Streaming Connection Options',['../group__stan_conn_opts_group.html',1,'']]],
  ['streaming_20message_65',['Streaming Message',['../group__stan_msg_group.html',1,'']]],
  ['streaming_20subscription_66',['Streaming Subscription',['../group__stan_sub_group.html',1,'']]],
  ['streaming_20subscription_20options_67',['Streaming Subscription Options',['../group__stan_sub_opts_group.html',1,'']]],
  ['streams_68',['Streams',['../structjs_account_info.html#a17317abf03effdcdedc2003fca8adc71',1,'jsAccountInfo']]],
  ['subject_69',['Subject',['../structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html#aa99e6ee3bef1c22243f01544181315fe',1,'jsOptions::jsOptionsStream::jsOptionsStreamPurge::Subject()'],['../structjs_stream_state_subject.html#aa766824a7f8b69db592971af3262640e',1,'jsStreamStateSubject::Subject()']]],
  ['subjects_70',['Subjects',['../structjs_stream_state.html#a4af56e8bee7262ab050f2a25114c5909',1,'jsStreamState::Subjects()'],['../structjs_stream_config.html#a0c5f3354073dbe72650e3db7f59a47af',1,'jsStreamConfig::Subjects()']]],
  ['subjectsfilter_71',['SubjectsFilter',['../structjs_options_1_1js_options_stream_1_1js_options_stream_info.html#af874e0f5aa15fb2a41504631ed786e6d',1,'jsOptions::jsOptionsStream::jsOptionsStreamInfo']]],
  ['subjectslen_72',['SubjectsLen',['../structjs_stream_config.html#ab2186aae798df6c222b3fa69e31597e1',1,'jsStreamConfig']]],
  ['subscribing_73',['Subscribing',['../group__conn_sub_group.html',1,'(Global Namespace)'],['../group__js_sub_group.html',1,'(Global Namespace)'],['../group__stan_conn_sub_group.html',1,'(Global Namespace)']]],
  ['subscription_74',['Subscription',['../group__sub_group.html',1,'']]]
];
